--[[
Class to manage the layout tab of the config dialog for the add-on.
--]]

uab.classes.LayoutTab = uab.mixins.aceOO.Class(uab.interfaces.cfgdlgtab)

function uab.classes.LayoutTab.prototype:init(frame)
    uab.classes.LayoutTab.super.prototype.init(self)
    
    self.frame = frame
    self.frames = {}
    self.frames.controls = getglobal(self.frame:GetName().."Controls")
    
    self.frames.layout = getglobal(self.frames.controls:GetName().."Layout")
    self.frames.layout.uabobj = self
    
    self.frames.options = getglobal(self.frames.controls:GetName().."LayoutOptions")
    
    self:SetupLayouts()
    self:SetLayoutOptionFrames()
end    

function uab.classes.LayoutTab.prototype:SetupLayouts()
    uab.classes.LayoutTab.InitDropdown = self
    UIDropDownMenu_Initialize(self.frames.layout,
        function()
            if uab.classes.LayoutTab.InitDropdown then
                uab.classes.LayoutTab.InitDropdown:FillLayouts()
            else
                this:GetParent().uabobj:FillLayouts()
            end
        end)
	UIDropDownMenu_SetWidth(110, self.frames.layout)
	UIDropDownMenu_SetButtonWidth(24, self.frames.layout)
	UIDropDownMenu_JustifyText("LEFT", self.frames.layout)
    uab.classes.LayoutTab.InitDropdown = nil
end

function uab.classes.LayoutTab.prototype:SelectLayout(selector, selection)
    UIDropDownMenu_SetSelectedID(self.frames.layout, selector:GetID())
    
    uab.db.profile.layout = selection
    uab.main:LayoutChanged()
end

function uab.classes.LayoutTab.prototype:FillLayouts()
    local managers = uab:GetManagers()
    local selmgr
    
    for _, mgr in pairs(managers) do
        -- Add the name for this manager to the dropdown
        UIDropDownMenu_AddButton({
            text = mgr.manager:GetDisplayName(),
            func = uab.DropDownSelect,
            arg1 = self,
            arg2 = { func = "SelectLayout", arg1 = mgr.manager:GetName() }})

        -- if the name matches the configured layout name, then
        -- mark this one as the current selection
        if mgr.manager:GetName() == uab.db.profile.layout then
            selmgr = mgr.manager:GetDisplayName()
        end
    end

    UIDropDownMenu_SetSelectedName(self.frames.layout, selmgr)
end

function uab.classes.LayoutTab.prototype:SelectCurrentLayout()
    local managers = uab:GetManagers()
    local selmgr
    
    for _, mgr in pairs(managers) do
        -- if the name matches the configured layout name, then
        -- mark this one as the current selection
        if mgr.manager:GetName() == uab.db.profile.layout then
            selmgr = mgr.manager:GetDisplayName()
            break
        end
    end

    UIDropDownMenu_SetSelectedName(self.frames.layout, selmgr)
    self:SetLayoutOptionFrames()
end

function uab.classes.LayoutTab.prototype:SetLayoutOptionFrames()
    if self.frames.currentoptions then
        self.frames.currentoptions:Hide()
    end
    
    --[[
    uab.db.profile.layout is the current layout name, so update
    the displayed option frames to the frames associated with
    that layout config instance.
    --]]
    
    local managers = uab:GetManagers()
    local layoutname = uab.db.profile.layout
    local manager = managers[layoutname].manager
    
    if not managers[layoutname].layout then
        managers[layoutname].layout = manager:GetLayout("main", uab.db.profile.layoutSettings[layoutname])
    end

    local layout = managers[layoutname].layout
	local config = layout:GetConfig()
    local cfgframe = config:GetFrame(self.frames.options)
    
    self.frames.currentoptions = cfgframe

    cfgframe:Show()
end

function uab.classes.LayoutTab.prototype:GetFrame()
    return self.frame
end
                
function uab.classes.LayoutTab.prototype:Activate()
    self.frames.controls:Show()
end
                
function uab.classes.LayoutTab.prototype:Deactivate()
    self.frames.controls:Hide()
end

